# Packaging of Machine Learning Pipeline

The pipeline features

- open source classes
- in house package classes
- feature selection during pipeline
- score new data

We will use the house price dataset available on [Kaggle.com](https://www.kaggle.com/datasets/mazhar01/real-state-website-data).

<table style="width:100%">
  <tr>
    <td style="text-align: center;"><img src="https://i.imgur.com/moNYLOr.png[/img]" width="570px" height=240px/></td>
   </tr>
</table>